/*
 * SourceMod Radio
 *
 * Adds !radio or using !browse www.site.com to SourceMod
 *
 * Coded by dubbeh - www.dubbeh.net
 *
 * Licensed under the GPLv3
 *
 */

#pragma semicolon 1
#include <sourcemod>
#include <clientprefs>
#include <colors>

// Fix thanks to Dr. McKay - REQUIRE_PLUGIN is set by default
#if defined REQUIRE_PLUGIN
 #undef REQUIRE_PLUGIN
#endif
#include <updater>
#define REQUIRE_PLUGIN

#define PLUGIN_NAME					"SourceMod Radio"
#define PLUGIN_VERSION				"1.0.0.19"
#define MAX_STATION_NAME_SIZE		32
#define MAX_MOTD_URL_SIZE			192 // MOTD message size can be 192 bytes maximum


public Plugin SourceModRadio = 
{
	name = PLUGIN_NAME, 
	author = "dubbeh", 
	description = "Radio stations plugin for SourceMod", 
	version = PLUGIN_VERSION, 
	url = "www.dubbeh.net"
};

/* cVar Handles */
ConVar g_cVarEnable = null;
ConVar g_cVarStationAdvert = null;
ConVar g_cVarWelcomeMsg = null;
ConVar g_cVarLogging = null;
ConVar g_cVarAutoplay = null;
ConVar g_cVarVolCont = null;
ConVar g_cVarInitialConnectVolume = null;
ConVar g_cVarAutoUpdate = null;

/* Radio station vars */
Menu g_mRadioBaseMenu = null;
Menu g_mRadioStationsMenu = null;
Menu g_mRadioVolumeMenu = null;
char g_szRadioOffPage[MAX_MOTD_URL_SIZE] = "about:blank";
Handle g_hArrayRadioStationNames = INVALID_HANDLE;
Handle g_hArrayRadioStationURLs = INVALID_HANDLE;
char g_szConfigFile[] = "sourcemod/plugin.radio.cfg";
char g_szRadioStationsBasicFile[] = "cfg/sourcemod/radiostations.ini";
char g_szRadioStationsVolumeFile[] = "cfg/sourcemod/radiostations_vol.ini";
char g_szVolumeWrapperURL[MAX_MOTD_URL_SIZE + 1] = "http://dubbeh.net/sm/rvw.html";
char g_szBrowseFixURL[MAX_MOTD_URL_SIZE + 1] = "http://dubbeh.net/sm/rbf.php";
char g_szUpdateURL[] = "http://update.dubbeh.net/radio/radio.txt";
Handle g_hCookieSavedStationDirect = INVALID_HANDLE;
Handle g_hCookieSavedStationVolume = INVALID_HANDLE;
Handle g_hCookieSavedVolume = INVALID_HANDLE;
EngineVersion g_EngineVersion = Engine_Unknown;
bool g_bUpdaterAvail = false;


public void OnPluginStart()
{
	CreateConVar("sm_radio_version", PLUGIN_VERSION, "SourceMod Radio version", FCVAR_SPONLY | FCVAR_REPLICATED | FCVAR_NOTIFY | FCVAR_DONTRECORD);
	g_cVarEnable = CreateConVar("sm_radio_enable", "1.0", "Enable SourceMod Radio", 0, true, 0.0, true, 1.0);
	g_cVarStationAdvert = CreateConVar("sm_radio_advert", "1.0", "Enable advertising the users radio station choice", 0, true, 0.0, true, 1.0);
	g_cVarWelcomeMsg = CreateConVar("sm_radio_welcome", "1.0", "Enable the welcome message", 0, true, 0.0, true, 1.0);
	g_cVarLogging = CreateConVar("sm_radio_logging", "1.0", "Enable logging to the server console and log file", 0, true, 0.0, true, 1.0);
	g_cVarAutoplay = CreateConVar("sm_radio_autoplay", "1.0", "Enable auto playing a users radio choice on map change", 0, true, 0.0, true, 1.0);
	g_cVarVolCont = CreateConVar("sm_radio_vol_cont", "1.0", "Enable volume control under all supported mods", 0, true, 0.0, true, 1.0);
	g_cVarInitialConnectVolume = CreateConVar("sm_radio_init_conn_vol", "0.10", "Initial volume set for a user on first connect", 0, true, 0.01, true, 1.0);
	g_cVarAutoUpdate = CreateConVar("sm_radio_auto_update", "1.0", "Enable the plugin to automatically update (if available updates found)", 0, true, 0.0, true, 1.0);
	
	if ((g_cVarEnable == null) || 
		(g_cVarStationAdvert == null) || 
		(g_cVarWelcomeMsg == null) || 
		(g_cVarLogging == null) || 
		(g_cVarAutoplay == null) || 
		(g_cVarVolCont == null) ||
		(g_cVarInitialConnectVolume == null) ||
		(g_cVarAutoUpdate == null))
	    SetFailState("[SM-RADIO] Error - Unable to create a console var");
	
	if (((g_hArrayRadioStationNames = CreateArray(MAX_STATION_NAME_SIZE + 1, 0)) == INVALID_HANDLE) || 
		((g_hArrayRadioStationURLs = CreateArray(MAX_MOTD_URL_SIZE + 1, 0)) == INVALID_HANDLE))
	{
		SetFailState("[SM-RADIO] Error - Unable to create the station arrays");
	}
	
	LoadTranslations("radio.phrases");
	
	RegConsoleCmd("sm_radio", Command_Radio);
	RegConsoleCmd("sm_radiooff", Command_RadioOff);
	RegConsoleCmd("sm_browse", Command_Browse);
	
	ServerCommand("exec %s", g_szConfigFile);
	
	g_hCookieSavedStationDirect = RegClientCookie("Radio Saved Station Direct", "Radio Saved Station Direct", CookieAccess_Private);
	g_hCookieSavedStationVolume = RegClientCookie("Radio Saved Station Volume", "Radio Saved Station Volume", CookieAccess_Private);
	g_hCookieSavedVolume = RegClientCookie("Radio Saved Volume", "Radio Saved Volume", CookieAccess_Private);
	
	g_EngineVersion = GetEngineVersion();
	
	if (g_EngineVersion == Engine_CSGO)
	{
		if (g_cVarLogging.IntValue)
		{
			LogMessage("[SM-RADIO] Running under CS:GO detected");
		}
	}
	else if (g_EngineVersion == Engine_Unknown)
	{
		if (g_cVarLogging.IntValue)
		{
			LogMessage("[SM-RADIO] Unknown mod found - Please contact the SourceMod authors for support");
		}
		
		SetFailState("[SM-RADIO] Unknown mod found - Please contact the SourceMod authors for support");
	}
	
	// Auto create the config file, if it doesn't exist
	AutoExecConfig(true, "plugin.radio", "sourcemod");
	
}

public OnAllPluginsLoaded()
{
	g_bUpdaterAvail = LibraryExists("updater");
}

public OnLibraryAdded(const char []name)
{
    if (LibraryExists("updater"))
    {
    	g_bUpdaterAvail = true;
    }
}

public OnLibraryRemoved(const char []name)
{
	if (StrEqual(name, "updater"))
	{
		g_bUpdaterAvail = false;
	}
}

public void OnPluginEnd()
{
	ClearArray(g_hArrayRadioStationNames);
	FreeHandle(g_hArrayRadioStationNames);
	ClearArray(g_hArrayRadioStationURLs);
	FreeHandle(g_hArrayRadioStationURLs);
}

public void OnMapStart()
{
	ServerCommand("exec %s", g_szConfigFile);
	strcopy(g_szRadioOffPage, sizeof(g_szRadioOffPage), "about:blank");
	
	if (!CreateRadioMenus())
		SetFailState("[SM-RADIO] Error - There was a problem creating a menu");
		
	if (g_cVarAutoUpdate.IntValue)
	{
		if (g_bUpdaterAvail)
		{
			Updater_AddPlugin(g_szUpdateURL);
		}
		else
		{
			LogMessage("[SM-RADIO] Auto-Updating enabled but unable to find the SourceMod Updater plugin.");
			LogMessage("[SM-RADIO] Download it from : https://forums.alliedmods.net/showthread.php?t=169095");
		}
	}
}

public void OnMapEnd()
{
	delete g_mRadioBaseMenu;
	g_mRadioBaseMenu = null;
	
	delete g_mRadioStationsMenu;
	g_mRadioStationsMenu = null;
	
	delete g_mRadioVolumeMenu;
	g_mRadioVolumeMenu = null;
}

public void OnClientPostAdminCheck(int client)
{
	if ((!client) || !g_cVarEnable.IntValue || !IsClientConnected(client) || IsFakeClient(client))
		return;
	
	// Extra check here - Just incase we don't need to waste a thread
	if (g_cVarWelcomeMsg.IntValue || g_cVarAutoplay.IntValue)
	    CreateTimer(30.0, WelcomeAdvertTimer, GetClientSerial(client));
}

public Action WelcomeAdvertTimer(Handle timer, any iClientSerial)
{
	char szClientName[MAX_NAME_LENGTH] = "";
	char szRadioStation[MAX_MOTD_URL_SIZE + 1] = "";
	char szRadioVolume[10] = "";
	
	int iClient = GetClientFromSerial(iClientSerial);
	
	if (IsClientConnected(iClient) && IsClientInGame(iClient))
	{
		if (g_cVarWelcomeMsg.IntValue)
		{
			GetClientName(iClient, szClientName, sizeof(szClientName));
			CPrintToChat(iClient, "%T", "Welcome", LANG_SERVER, szClientName);
			CPrintToChat(iClient, "%T", "Radio Command Info", LANG_SERVER);
		}
		
		if (g_cVarAutoplay.IntValue && AreClientCookiesCached(iClient))
		{
			if (g_cVarVolCont.IntValue)
			{
				GetClientCookie(iClient, g_hCookieSavedStationVolume, szRadioStation, sizeof(szRadioStation));
				GetClientCookie(iClient, g_hCookieSavedVolume, szRadioVolume, sizeof(szRadioVolume));
				LoadMOTDPanel(iClient, "SourceMod Radio", Radio_Volume_Wrapper(iClient, szRadioStation, szRadioVolume), false);
			}
			else
			{
				GetClientCookie(iClient, g_hCookieSavedStationDirect, szRadioStation, sizeof(szRadioStation));
				LoadMOTDPanel(iClient, "SourceMod Radio", szRadioStation, false);
			}
		}
	}
	
	return Plugin_Stop;
}

void LoadMOTDPanel(int client, char[] title, char[] page, bool display)
{
	if (!IsClientConnected(client) || !IsClientInGame(client))
		return;
	
	Handle kv = INVALID_HANDLE;
	
	kv = CreateKeyValues("data");
	KvSetString(kv, "title", title);
	KvSetNum(kv, "type", MOTDPANEL_TYPE_URL);
	KvSetString(kv, "msg", page);
	ShowVGUIPanel(client, "info", kv, display);
	CloseHandle(kv);
}

char CSGO_Browse_Fix(int iClient, char[] szURL)
{
	char szBuffer[256] = "";
	
	Format(szBuffer, sizeof(szBuffer), "%s?url=%s", g_szBrowseFixURL, szURL);
	if (IsURLTooLong(szBuffer))
	{
		if (IsClientConnected(iClient) && IsClientInGame(iClient))
		{
			LogMessage("[SM-RADIO] Warning: URL \"%s\" exceeds the 192 bytes limit and will end up truncated.");
			CPrintToChat(iClient, "%T", "Radio URL Too Long", LANG_SERVER);
		}
	}
	
	return szBuffer;
}

char Radio_Volume_Wrapper(int iClient, char[] szStationURL, char[] szVolume)
{
	char szURL[256] = "";
	
	Format(szURL, sizeof(szURL), "%s?url=%s&volume=%s", g_szVolumeWrapperURL, szStationURL, szVolume);
	if (IsURLTooLong(szURL))
	{
		if (IsClientConnected(iClient) && IsClientInGame(iClient))
		{
			LogMessage("[SM-RADIO] Warning: URL \"%s\" exceeds the 192 bytes limit and will end up truncated.", szURL);
			CPrintToChat(iClient, "%T", "Radio URL Too Long", LANG_SERVER);
		}
	}
	
	return szURL;
}

bool IsURLTooLong(char[] szBuffer)
{
	if (strlen(szBuffer) > MAX_MOTD_URL_SIZE)
		return true;
	
	return false;
}

void FreeHandle(Handle hHandle)
{
	if (hHandle != INVALID_HANDLE)
	{
		CloseHandle(hHandle);
		hHandle = INVALID_HANDLE;
	}
}

void LoadOffPage(int iClient)
{
	char szClientName[MAX_NAME_LENGTH + 1] = "";
	
	if (IsClientConnected(iClient) && IsClientInGame(iClient))
	{
		LoadMOTDPanel(iClient, "SourceMod Radio", g_szRadioOffPage, false);
		SetClientCookie(iClient, g_hCookieSavedStationDirect, "");
		SetClientCookie(iClient, g_hCookieSavedStationVolume, "");
		
		if (g_cVarStationAdvert.IntValue)
		{
			GetClientName(iClient, szClientName, sizeof(szClientName));
			CPrintToChatAll("%T", "Stopped Listening", LANG_SERVER, szClientName);
		}
	}
}

bool CreateRadioMenus()
{
	GetRadioStationsFromFile();
	if ((g_mRadioBaseMenu = CreateRadioBaseMenu()) == null || 
		(g_mRadioStationsMenu = CreateRadioStationsMenu()) == null || 
		(g_mRadioVolumeMenu = CreateRadioVolumeMenu()) == null)
	{
	    return false;
	}
	
	return true;
}

Menu CreateRadioBaseMenu()
{
	Menu mMenu = null;
	char szTranslation[64] = "";
	
	mMenu = new Menu(Handler_BaseRadioMenu);
	mMenu.SetTitle("SourceMod Radio:");
	Format(szTranslation, sizeof(szTranslation), "%T", "Select Station", LANG_SERVER);
	mMenu.AddItem("1", szTranslation);
	if (g_cVarVolCont.IntValue)
	{
		Format(szTranslation, sizeof(szTranslation), "%T", "Volume", LANG_SERVER);
		mMenu.AddItem("2", szTranslation);
	}
	Format(szTranslation, sizeof(szTranslation), "%T", "Turn Off", LANG_SERVER);
	mMenu.AddItem("3", szTranslation);
	
	return mMenu;
}

public Handler_BaseRadioMenu(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	if (maAction == MenuAction_Select)
	{
		char szSelection[32] = "";
		
		mMenu.GetItem(iParam, szSelection, sizeof(szSelection));
		
		if (szSelection[0] == '1')
		{
			if (g_mRadioStationsMenu != INVALID_HANDLE)
				g_mRadioStationsMenu.Display(iClient, MENU_TIME_FOREVER);
			else
				SetFailState("[SM-RADIO] Stations menu appears to be null. Please report this error to the author.");
		}
		else if (szSelection[0] == '2')
		{
			if (g_mRadioVolumeMenu != INVALID_HANDLE)
				g_mRadioVolumeMenu.Display(iClient, MENU_TIME_FOREVER);
			else
				SetFailState("[SM-RADIO] Volume menu appears to be null. Please report this error to the author.");
		}
		else if (szSelection[0] == '3')
		{
			LoadOffPage(iClient);
		}
	}
}

Menu CreateRadioStationsMenu()
{
	Menu mMenu = null;
	int iIndex = 0;
	int iArraySize = 0;
	char szStationIndex[11] = "";
	char szTranslation[64] = "";
	char szStationName[MAX_MOTD_URL_SIZE + 1] = "";
	
	mMenu = new Menu(Handler_PlayRadioStation);
	Format(szTranslation, sizeof(szTranslation), "%T:", "Stations Menu Title", LANG_SERVER);
	mMenu.SetTitle(szTranslation);
	iArraySize = GetArraySize(g_hArrayRadioStationNames);
	
	for (iIndex = 0; iIndex < iArraySize; iIndex++)
	{
		GetArrayString(g_hArrayRadioStationNames, iIndex, szStationName, sizeof(szStationName));
		Format(szStationIndex, sizeof(szStationIndex), "%d", iIndex);
		mMenu.AddItem(szStationIndex, szStationName);
	}
	
	mMenu.ExitBackButton = true;
	return mMenu;
}

public Handler_PlayRadioStation(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	if (maAction == MenuAction_Cancel)
	{
		if (iParam == MenuCancel_ExitBack)
			g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	}
	else if (maAction == MenuAction_Select)
	{
		char szRadioStationIndex[10] = "";
		char szClientName[MAX_NAME_LENGTH] = "";
		char szStationName[MAX_STATION_NAME_SIZE] = "";
		char szStationURL[MAX_MOTD_URL_SIZE + 1] = "";
		int iStation = 0;
		char szSavedVolume[12] = "";
		char szInitialConnectVolume[10] = "";
		
		mMenu.GetItem(iParam, szRadioStationIndex, sizeof(szRadioStationIndex));
		iStation = StringToInt(szRadioStationIndex);
		GetArrayString(g_hArrayRadioStationNames, iStation, szStationName, sizeof(szStationName));
		GetArrayString(g_hArrayRadioStationURLs, iStation, szStationURL, sizeof(szStationURL));
		
		
		if (g_cVarVolCont.IntValue)
		{
			SetClientCookie(iClient, g_hCookieSavedStationVolume, szStationURL);
			GetClientCookie(iClient, g_hCookieSavedVolume, szSavedVolume, sizeof(szSavedVolume));
			
			if (!szSavedVolume[0])
			{
				FloatToString(g_cVarInitialConnectVolume.FloatValue, szInitialConnectVolume, sizeof(szInitialConnectVolume));
				
				SetClientCookie(iClient, g_hCookieSavedVolume, szInitialConnectVolume);
				strcopy(szSavedVolume, sizeof(szSavedVolume), szInitialConnectVolume);
			}
			
			if (g_EngineVersion == Engine_CSGO)
			{
				LoadMOTDPanel(iClient, PLUGIN_NAME, Radio_Volume_Wrapper(iClient, szStationURL, szSavedVolume), false);
			}
			else
			{
				ShowMOTDPanel(iClient, PLUGIN_NAME, Radio_Volume_Wrapper(iClient, szStationURL, szSavedVolume), MOTDPANEL_TYPE_URL);
			}
		}
		else
		{
			SetClientCookie(iClient, g_hCookieSavedStationDirect, szStationURL);
			
			if (g_EngineVersion == Engine_CSGO)
				LoadMOTDPanel(iClient, PLUGIN_NAME, szStationURL, false);
			else
				ShowMOTDPanel(iClient, PLUGIN_NAME, szStationURL, MOTDPANEL_TYPE_URL);
		}
		
		if (g_cVarStationAdvert.IntValue)
		{
			GetClientName(iClient, szClientName, sizeof(szClientName));
			CPrintToChatAll("%T", "Started Listening", LANG_SERVER, szClientName, szStationName);
		}
		
	}
}

Menu CreateRadioVolumeMenu()
{
	Menu mMenu = null;
	char szTranslation[64] = "";
	
	mMenu = new Menu(Handler_VolumeMenu);
	
	Format(szTranslation, sizeof(szTranslation), "%T:", "Volume Menu Title", LANG_SERVER);
	mMenu.SetTitle(szTranslation);
	mMenu.AddItem("0.01", "1%");
	mMenu.AddItem("0.05", "5%");
	mMenu.AddItem("0.10", "10%");
	mMenu.AddItem("0.20", "20%");
	mMenu.AddItem("0.40", "40%");
	mMenu.AddItem("0.60", "60%");
	mMenu.AddItem("0.80", "80%");
	mMenu.AddItem("1.0", "100%");
	mMenu.ExitBackButton = true;
	return mMenu;
}

public Handler_VolumeMenu(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szStationURL[MAX_MOTD_URL_SIZE + 1] = "";
	char szStationVolume[32] = "";
	
	if (maAction == MenuAction_Cancel)
	{
		if (iParam == MenuCancel_ExitBack)
			g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	}
	else if (maAction == MenuAction_Select)
	{
		mMenu.GetItem(iParam, szStationVolume, sizeof(szStationVolume));
		SetClientCookie(iClient, g_hCookieSavedVolume, szStationVolume);
		CPrintToChat(iClient, "%T", "Volume Set To", LANG_SERVER, szStationVolume);
		
		GetClientCookie(iClient, g_hCookieSavedStationVolume, szStationURL, sizeof(szStationURL));
		
		if (szStationURL[0])
		{
			if (g_EngineVersion == Engine_CSGO)
				LoadMOTDPanel(iClient, PLUGIN_NAME, Radio_Volume_Wrapper(iClient, szStationURL, szStationVolume), false);
			else
				ShowMOTDPanel(iClient, PLUGIN_NAME, Radio_Volume_Wrapper(iClient, szStationURL, szStationVolume), MOTDPANEL_TYPE_URL);
		}
	}
}

void GetRadioStationsFromFile()
{
	char szLineBuffer[256] = "";
	char szTempBuffer[MAX_MOTD_URL_SIZE + 1] = "";
	int iIndex = 0;
	int iPos = -1;
	int iNumOfStations = 0;
	File hFile = null;
	char szRadioStationsFile[PLATFORM_MAX_PATH] = "";
	
	
	if (g_cVarVolCont.IntValue)
		strcopy(szRadioStationsFile, sizeof(szRadioStationsFile), g_szRadioStationsVolumeFile);
	else
		strcopy(szRadioStationsFile, sizeof(szRadioStationsFile), g_szRadioStationsBasicFile);
	
	if (g_cVarLogging.IntValue)
		LogMessage("[SM-RADIO] Loading the radio stations from \"%s\"", szRadioStationsFile);
	
	ClearArray(g_hArrayRadioStationNames);
	ClearArray(g_hArrayRadioStationURLs);
	iNumOfStations = 0;
	
	if ((hFile = OpenFile(szRadioStationsFile, "r")) != INVALID_HANDLE)
	{
		while (!hFile.EndOfFile() && hFile.ReadLine(szLineBuffer, sizeof(szLineBuffer)))
		{
			TrimString(szLineBuffer);
			
			if ((szLineBuffer[0] != '\0') && (szLineBuffer[0] != ';') && (szLineBuffer[0] != '/') && (szLineBuffer[1] != '/') && (szLineBuffer[0] == '"') && (szLineBuffer[0] != '\n') && (szLineBuffer[1] != '\n'))
			{
				iIndex = 0;
				if ((iPos = BreakString(szLineBuffer[iIndex], szTempBuffer, sizeof(szTempBuffer))) != -1)
				{
					iIndex += iPos;
					
					if (!strcmp("Off Page", szTempBuffer, false))
					{
						strcopy(g_szRadioOffPage, sizeof(g_szRadioOffPage), szLineBuffer[iIndex]);
					}
					else if (!strcmp("Browse Fix", szTempBuffer, false))
					{
						strcopy(g_szBrowseFixURL, sizeof(g_szBrowseFixURL), szLineBuffer[iIndex]);
					}
					else if (!strcmp("Volume Wrapper", szTempBuffer, false))
					{
						strcopy(g_szVolumeWrapperURL, sizeof(g_szVolumeWrapperURL), szLineBuffer[iIndex]);
					}
					else
					{
						PushArrayString(g_hArrayRadioStationNames, szTempBuffer);
						PushArrayString(g_hArrayRadioStationURLs, szLineBuffer[iIndex]);
						iNumOfStations++;
					}
				}
			}
		}
		
		hFile.Close();
		hFile = null;
		if (g_cVarLogging.IntValue)
			LogMessage("[SM-RADIO] Finishing parsing \"%s\" - Found %d radio stations", szRadioStationsFile, iNumOfStations);
		return;
	}
	
	if (g_cVarLogging.IntValue)
		LogMessage("[SM-RADIO] Unable to open \"%s\"", szRadioStationsFile);
	
	SetFailState("[SM-RADIO] Unable to open the \"%s\" file", szRadioStationsFile);
	return;
}

public Action Command_Radio(int client, int args)
{
	if (g_cVarEnable.IntValue)
	{
		if (g_mRadioBaseMenu != null)
			g_mRadioBaseMenu.Display(client, MENU_TIME_FOREVER);
		else
			SetFailState("[SM-RADIO] Base menu appears to be null. Please report this error to the author.");
	}
	
	return Plugin_Handled;
}

public Action Command_Browse(int client, int args)
{
	if (g_cVarEnable.IntValue)
	{
		if (args == 1)
		{
			char szWebsite[MAX_MOTD_URL_SIZE + 1] = "";
			
			GetCmdArg(1, szWebsite, sizeof(szWebsite));
			
			if (g_EngineVersion == Engine_CSGO)
				ShowMOTDPanel(client, "SourceMod Browse", CSGO_Browse_Fix(client, szWebsite), MOTDPANEL_TYPE_URL);
			else
				ShowMOTDPanel(client, "SourceMod Browse", szWebsite, MOTDPANEL_TYPE_URL);
		}
		else
		{
			CReplyToCommand(client, "Invalid browse format");
			CReplyToCommand(client, "Usage: sm_browse \"www.website.com\"");
		}
	}
	
	return Plugin_Handled;
}

public Action Command_RadioOff(int client, int args)
{
	if (g_cVarEnable.IntValue)
		LoadOffPage(client);
	
	return Plugin_Handled;
}
